////////////////////////////////////////////////////////////////////////////////
//Descrition:   Quick pic 876/877 demo program                                 /
//              simple 19200 rs232 menu, 2 lamps and analog input              /
//Firmware:     fnt.c                                                          /
//Hardware:                                                                    /
//Processor:    PIC16f876 or PIC16f877                                         /
////////////////////////////////////////////////////////////////////////////////
//Revision history                                                             /
//No.   Date        Description                                                /
//-----------------------------------------------------------------------------/
//00    2006/05/05  Initial release                                            /
////////////////////////////////////////////////////////////////////////////////
#define debugme 0           //0=standalone / 1=debug
#define proc    877         //877 or 876, 877 when wired for ccs demo-40pin
////////////////////////////////////////////////////////////////////////////////
#include "fnt.h"
////////////////////////////////////////////////////////////////////////////////

#define mon_lamp pin_b5     //connect to lamp1
#define test_lamp pin_b4    //connect to lamp2

int1 report_adc=0;          //1=do it, 0=did it
int1 report_continuous=0;   //0=off, 1=continuous adc report
int1 report_menu=0;         //1=do it, 0=did it
int8 report_unit=0;         //0=hex, 1=decimal
int1 report_speed=0;        //0=slow, 1=fast


#int_RDA
RDA_isr()
{
int8 temp;

do
    {
    if (kbhit())
        {
        temp=getc();
        switch(temp){
            case 'u':
            case 'U':
                report_unit=report_unit+1;
                if (report_unit==3)
                    report_unit=0;
                break;
            case 's':
            case 'S':
                report_speed=!report_speed;
                break;
            case 'c':
            case 'C':
                report_continuous=!report_continuous;
                break;
            case 'a':
            case 'A':
                report_adc=1;
                break;
            case '=':
            case '+':
                output_high(test_lamp);
                break;
            case '_':
            case '-':
                output_low(test_lamp);
                break;
            case '?':
            case '/':
                report_menu=1;
                break;
            default:
                break;
            }
        }
    }while(kbhit());
}






void main(){
////////////////////////////////////////////////////////////////////////////////
int16 loop_counter=0;
int1 mon_stat;
int8 i;
////////////////////////////////////////////////////////////////////////////////
setup_adc_ports(AN0);
setup_adc(ADC_CLOCK_INTERNAL);
setup_spi(FALSE);
setup_timer_0(RTCC_INTERNAL|RTCC_DIV_1);
setup_timer_1(T1_DISABLED);
setup_timer_2(T2_DISABLED,0,1);
enable_interrupts(INT_RDA);
enable_interrupts(GLOBAL);
////////////////////////////////////////////////////////////////////////////////


delay_ms(250);
set_adc_channel(0);
report_menu=1;



while(true){
////////////////////////////////////////////////////////////////////////////////
restart_wdt();

loop_counter++;
if (loop_counter==0)
    {
    if (report_speed==1)
      loop_counter=61000;
    mon_stat=!mon_stat;
    output_bit(mon_lamp,mon_stat);
    if (report_continuous)
        {
        if (report_unit==0)
            printf("\rADC: 0x%3lX",read_adc()>>6);
        if (report_unit==1)
            printf("\rADC: %04lu",read_adc()>>6);
        if (report_unit==2)
            {
            printf("\rADC: |");
            for (i=0;i<read_adc()>>11;i++)
                putc('X');
            for (i=i;i<31;i++)
                putc(' ');
            putc('|');
            }
        }
    }


if (report_adc)
    {
    report_adc=0;
        if (report_unit==0)
            printf("\rADC: 0x%3lX",read_adc()>>6);
        if (report_unit==1)
            printf("\rADC: %04lu",read_adc()>>6);
        if (report_unit==2)
            {
            printf("\rADC: |");
            for (i=0;i<read_adc()>>11;i++)
                putc('X');
            for (i=i;i<31;i++)
                putc(' ');
            putc('|');
            }
    }


if (report_menu)
    {
    printf("\r\r");
    printf("A or a  Single ADC Tx\r");
    printf("C or c  Continuous ADC Tx\r");
    printf("U or u  Switch between hex, decimal and bar graph\r");
    printf("+ or =  LED on\r");
    printf("- or _  LED off\r");
    printf("S or s  Report speed\r");
    printf("? or /  This menu\r\r");
    report_menu=0;
    }

////////////////////////////////////////////////////////////////////////////////
}
}
